@@ -7,6 +7,8 @@ use feature    qw(say);
 use List::Util qw(any shuffle first);
 use Data::Dumper;
 use Sort::Naturally qw(nsort);
+use MIME::Base64;
+use Compress::Zlib qw(compress);
 use Hash::Fold fold => { array_delimiter => ':' };
 use Pheno::Ranker::Metrics;
 
@@ -187,7 +189,7 @@ sub compare_and_rank {
         push @{ $stat->{hamming_data} }, $score->{$key}{hamming};
         push @{ $stat->{jaccard_data} }, $score->{$key}{jaccard};
     }
- 
+
     # Stats are only computed once (no overhead)
     $stat->{hamming_stats} = add_stats( $stat->{hamming_data} );
     $stat->{jaccard_stats} = add_stats( $stat->{jaccard_data} );
@@ -635,7 +637,7 @@ sub remap_hash {
     my $edges  = $self->{edges};
     my $format = $self->{format};
     my $switch = $self->{retain_excluded_phenotypicFeatures};
-    my $out_hash;
+    my %out_hash;
 
     # Do some pruning excluded / included
     prune_excluded_included( $hash, $self );
@@ -726,7 +728,7 @@ sub remap_hash {
         if ( defined $edges && $val =~ /^HP:/ ) {
             my $ascendants =
               add_hpo_ascendants( $tmp_key_at_variable_level, $nodes, $edges );
-            $out_hash->{$_} = 1 for @$ascendants;    # weight 1 for now
+            $out_hash{$_} = 1 for @$ascendants;    # weight 1 for now
         }
 
         ##################
@@ -753,7 +755,7 @@ sub remap_hash {
             # We allow for assigning weights by TERM (e.g., 1D)
             # but VARIABLE level takes precedence to TERM
 
-            $out_hash->{$tmp_key_at_variable_level} =
+            $out_hash{$tmp_key_at_variable_level} =
 
               # VARIABLE LEVEL
               # NB: exists stringifies the weights
@@ -771,7 +773,7 @@ sub remap_hash {
         else {
 
             # Assign a weight of 1 if no users weights
-            $out_hash->{$tmp_key_at_variable_level} = 1;
+            $out_hash{$tmp_key_at_variable_level} = 1;
 
         }
 
@@ -788,7 +790,7 @@ sub remap_hash {
 
     # *** IMPORTANT ***
     # We have to return an object {} when undef
-    return $out_hash // {};
+    return \%out_hash // {};
 }
 
 sub add_hpo_ascendants {
@@ -937,8 +939,8 @@ sub add_id2key {
 
 sub create_binary_digit_string {
 
-    my ( $glob_hash, $cmp_hash ) = @_;
-    my $out_hash;
+    my ( $export, $weight, $glob_hash, $cmp_hash ) = @_;
+    my %out_hash;
 
     # *** IMPORTANT ***
     # Being a nested for, keys %{$glob_hash} does not need sorting
@@ -950,18 +952,39 @@ sub create_binary_digit_string {
 
         # One-hot encoding = Representing categorical data as numerical
         my ( $binary_str, $binary_str_weighted ) = ('') x 2;
+
         for my $key (@sorted_keys_glob_hash) {
-            my $ones  = (1) x $glob_hash->{$key};
-            my $zeros = (0) x $glob_hash->{$key};
-            $binary_str .= exists $cmp_hash->{$individual_id}{$key} ? 1 : 0;
-            $binary_str_weighted .=
-              exists $cmp_hash->{$individual_id}{$key} ? $ones : $zeros;
+            my $has_value = exists $cmp_hash->{$individual_id}{$key};
+            $binary_str .= $has_value ? '1' : '0';
+            if ( defined $weight ) {
+                $binary_str_weighted .=
+                  $has_value
+                  ? ( '1' x $glob_hash->{$key} )
+                  : ( '0' x $glob_hash->{$key} );
+            }
         }
-        $out_hash->{$individual_id}{binary_digit_string} = $binary_str;
-        $out_hash->{$individual_id}{binary_digit_string_weighted} =
+
+        # If weight is not defined, simply assign the unweighted string once.
+        $binary_str_weighted = $binary_str unless defined $weight;
+
+        $out_hash{$individual_id}{binary_digit_string} = $binary_str;
+        $out_hash{$individual_id}{binary_digit_string_weighted} =
           $binary_str_weighted;
+
+        if ( defined $export ) {
+
+            # Convert string => raw bytes > zlib-compres => Base64
+            $out_hash{$individual_id}{zlib_base64_binary_digit_string} =
+              binary_to_base64($binary_str);
+
+            $out_hash{$individual_id}{zlib_base64_binary_digit_string_weighted}
+              = defined $weight
+              ? binary_to_base64($binary_str_weighted)
+              : $out_hash{$individual_id}{zlib_base64_binary_digit_string};
+        }
+
     }
-    return $out_hash;
+    return \%out_hash;
 }
 
 sub parse_hpo_json {
@@ -1025,4 +1048,36 @@ sub guess_label {
     return $input_string;
 }
 
+sub binary_to_base64 {
+
+    my $binary_string = shift;
+
+    # Convert binary string (e.g. "0010...") to raw bytes
+    my $raw_data = pack( "B*", $binary_string );
+
+    # Compress the raw data (note: compressing very short data may not save space)
+    my $compressed = compress($raw_data);
+
+    # Base64 encode the compressed data, without any newline breaks
+    return encode_base64( $compressed, "" );
+}
+
+sub _base64_to_binary {
+
+    my ( $b64_string, $original_length ) = @_;
+
+    # Decode the Base64 encoded compressed data
+    my $compressed_data = decode_base64($b64_string);
+
+    # Decompress the data back to raw bytes
+    my $raw_data = uncompress($compressed_data)
+      or die "Decompression failed: $Compress::Zlib::gzerrno\n";
+
+    # Convert the raw bytes back into a binary string (sequence of 0s and 1s)
+    my $binary_string = unpack( "B*", $raw_data );
+
+    # Trim the binary string to the original length to remove any padded bits
+    return substr( $binary_string, 0, $original_length );
+}
+
 1;
